# Django SaaS (Domain)

The domain module for building a SaaS product with Django.

## Install

```
pip install django-saas-domain
```

Then add it into your Django project `settings.py`:

```python
INSTALLED_APPS = [
    # ...
    "saas_base",  # django-saas-base is required
    "saas_domain",
]
```
